@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -167,7 +139,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
 
 
     private Object refreshSubscriptions(final JSONObject request, final ServerSession session) throws OXException, JSONException {
-        List<Subscription> subscriptionsToRefresh = new LinkedList<Subscription>();
+        List<Subscription> subscriptionsToRefresh = new LinkedList<>();
         TIntSet ids = new TIntHashSet();
         if (request.has("folder")) {
             final String folderId = request.getString("folder");
@@ -204,7 +176,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
     private Object listSubscriptions(JSONObject request, ServerSession session) throws JSONException, OXException {
         final JSONArray ids = request.getJSONArray(ResponseFields.DATA);
         final Context context = session.getContext();
-        final List<Subscription> subscriptions = new ArrayList<Subscription>(ids.length());
+        final List<Subscription> subscriptions = new ArrayList<>(ids.length());
         for (int i = 0, size = ids.length(); i < size; i++) {
             final int id = ids.getInt(i);
             final SubscriptionSource source = getDiscovery(session).getSource(context, id);
@@ -261,7 +233,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
 
     private List<Subscription> getSubscriptionsInFolder(ServerSession session, String folder, String secret) throws OXException {
         final List<SubscriptionSource> sources = getDiscovery(session).getSources();
-        final List<Subscription> allSubscriptions = new ArrayList<Subscription>(10);
+        final List<Subscription> allSubscriptions = new ArrayList<>(10);
         for (final SubscriptionSource subscriptionSource : sources) {
             final Collection<Subscription> subscriptions = subscriptionSource.getSubscribeService().loadSubscriptions(session.getContext(), folder, secret);
             allSubscriptions.addAll(subscriptions);
@@ -271,7 +243,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
 
     private List<Subscription> getAllSubscriptions(ServerSession session, String secret) throws OXException {
         final List<SubscriptionSource> sources = getDiscovery(session).getSources();
-        final List<Subscription> allSubscriptions = new ArrayList<Subscription>();
+        final List<Subscription> allSubscriptions = new ArrayList<>();
         for (final SubscriptionSource subscriptionSource : sources) {
             final SubscribeService subscribeService = subscriptionSource.getSubscribeService();
             final Collection<Subscription> subscriptions = subscribeService.loadSubscriptions(session.getContext(), session.getUserId(), secret);
@@ -298,7 +270,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
 
     private Map<String, String[]> getDynamicColumns(JSONObject request) throws JSONException {
         final List<String> identifiers = getDynamicColumnOrder(request);
-        final Map<String, String[]> dynamicColumns = new HashMap<String, String[]>();
+        final Map<String, String[]> dynamicColumns = new HashMap<>();
         for (final String identifier : identifiers) {
             final String columns = request.optString(identifier);
             if (columns != null && !columns.equals("")) {
@@ -315,7 +287,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
             return Arrays.asList(request.getString("dynamicColumnPlugins").split("\\s*,\\s*"));
         }
 
-        List<String> dynamicColumnIdentifiers = new ArrayList<String>();
+        List<String> dynamicColumnIdentifiers = new ArrayList<>();
         for (String paramName : request.keySet()) {
             if (!KNOWN_PARAMS.contains(paramName) && paramName.indexOf('.') >= 0) {
                 dynamicColumnIdentifiers.add(paramName);
@@ -352,9 +324,8 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         return createResponse(subscription, request.optString("__serverURL"), tz);
     }
 
-    private Object createResponse(final Subscription subscription, final String urlPrefix, TimeZone tz) throws JSONException, OXException {
-        final JSONObject object = new SubscriptionJSONWriter().write(subscription, subscription.getSource().getFormDescription(), urlPrefix, tz);
-        return object;
+    private Object createResponse(final Subscription subscription, final String urlPrefix, TimeZone tz) throws JSONException {
+        return new SubscriptionJSONWriter().write(subscription, subscription.getSource().getFormDescription(), urlPrefix, tz);
     }
 
     private Subscription loadSubscription(final int id, final ServerSession session, final String source, final String secret) throws OXException {
