@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2018-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -59,6 +31,7 @@ import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.generic.FolderUpdaterRegistry;
 import com.openexchange.groupware.generic.FolderUpdaterService;
+import com.openexchange.log.LogProperties;
 import com.openexchange.microsoft.graph.contacts.MicrosoftGraphContactsService;
 import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.OAuthAccount;
@@ -85,8 +58,10 @@ public class MicrosoftContactsSubscribeService extends AbstractOAuthSubscribeSer
 
     /**
      * Initialises a new {@link MicrosoftContactsSubscribeService}.
+     *
+     * @throws OXException
      */
-    public MicrosoftContactsSubscribeService(OAuthServiceMetaData metadata, ServiceLookup services) {
+    public MicrosoftContactsSubscribeService(OAuthServiceMetaData metadata, ServiceLookup services) throws OXException {
         super(metadata, SOURCE_ID, FolderObject.CONTACT, "Outlook.com", services);
     }
 
@@ -113,7 +88,7 @@ public class MicrosoftContactsSubscribeService extends AbstractOAuthSubscribeSer
 
     /**
      * Fetches all contacts in the foreground (blocking thread)
-     * 
+     *
      * @param account The {@link OAuthAccount}
      * @return A {@link List} with all fetched contacts
      * @throws OXException
@@ -125,7 +100,7 @@ public class MicrosoftContactsSubscribeService extends AbstractOAuthSubscribeSer
 
     /**
      * Schedules a task to fetch all contacts and executes it in the background
-     * 
+     *
      * @param threadPool the {@link ThreadPoolService}
      * @param folderUpdater The {@link FolderUpdaterService}
      * @param account The {@link OAuthAccount}
@@ -147,11 +122,12 @@ public class MicrosoftContactsSubscribeService extends AbstractOAuthSubscribeSer
         private final Subscription subscription;
 
         /**
-         * Initialises a new {@link BackgroundTask}.
-         * 
+         * Initializes a new {@link BackgroundTask}.
+         *
          * @param folderUpdater The folder updated
          * @param account The account
          * @param subscription The subscription
+         * @param backgroundTaskMarker The marker
          */
         BackgroundTask(FolderUpdaterService<Contact> folderUpdater, OAuthAccount account, Subscription subscription) {
             this.folderUpdater = folderUpdater;
@@ -161,6 +137,7 @@ public class MicrosoftContactsSubscribeService extends AbstractOAuthSubscribeSer
 
         @Override
         public Void call() throws Exception {
+            LogProperties.put(LogProperties.Name.SUBSCRIPTION_ADMIN, "true");
             try {
                 MicrosoftGraphContactsService contactsService = getServices().getService(MicrosoftGraphContactsService.class);
                 boolean hasMore = false;
@@ -175,6 +152,8 @@ public class MicrosoftContactsSubscribeService extends AbstractOAuthSubscribeSer
             } catch (Exception e) {
                 LOG.error("", e);
                 throw e;
+            } finally {
+                LogProperties.remove(LogProperties.Name.SUBSCRIPTION_ADMIN);
             }
         }
     }
