@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -68,6 +40,7 @@ import com.openexchange.groupware.generic.FolderUpdaterRegistry;
 import com.openexchange.groupware.generic.FolderUpdaterService;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
+import com.openexchange.log.LogProperties;
 import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.OAuthServiceMetaData;
 import com.openexchange.server.ServiceExceptionCode;
@@ -184,8 +157,9 @@ public class XingSubscribeService extends AbstractOAuthSubscribeService {
      *
      * @param oAuthServiceMetaData The {@link OAuthServiceMetaData}
      * @param services The {@link ServiceLookup}
+     * @throws OXException
      */
-    public XingSubscribeService(OAuthServiceMetaData oauthServiceMetadata, ServiceLookup services) {
+    public XingSubscribeService(OAuthServiceMetaData oauthServiceMetadata, ServiceLookup services) throws OXException {
         super(oauthServiceMetadata, "com.openexchange.subscribe.xing", FolderObject.CONTACT, "XING", services);
         this.services = services;
     }
@@ -215,7 +189,7 @@ public class XingSubscribeService extends AbstractOAuthSubscribeService {
             final FolderUpdaterService<Contact> folderUpdater = null == folderUpdaterRegistry ? null : folderUpdaterRegistry.<Contact> getFolderUpdater(subscription);
             if (null == threadPool || null == folderUpdater) {
                 // Retrieve all
-                final List<User> users = new ArrayList<User>(total);
+                final List<User> users = new ArrayList<>(total);
                 users.addAll(chunk);
                 int offset = chunk.size();
                 // Request remaining chunks
@@ -227,7 +201,7 @@ public class XingSubscribeService extends AbstractOAuthSubscribeService {
                 }
                 // All retrieved
                 LOG.info("Going to convert {} XING contacts for user {} in context {}", I(total), I(session.getUserId()), I(session.getContextId()));
-                final Map<String, String> photoUrlsMap = new HashMap<String, String>(total);
+                final Map<String, String> photoUrlsMap = new HashMap<>(total);
                 final PhotoHandler photoHandler = new CollectingPhotoHandler(photoUrlsMap);
                 final List<Contact> retval = convert(chunk, photoHandler, subscription, session);
                 LOG.info("Converted {} XING contacts for user {} in context {}", I(total), I(session.getUserId()), I(session.getContextId()));
@@ -242,18 +216,23 @@ public class XingSubscribeService extends AbstractOAuthSubscribeService {
 
                 @Override
                 public Void call() throws Exception {
-                    int off = startOffset;
-                    while (off < total) {
-                        final int remain = total - off;
-                        final List<User> chunk = xingAPI.getContactsFrom(userId, remain > maxLimit ? maxLimit : remain, off, null, userFields).getUsers();
-                        // Store them
-                        final List<Contact> convertees = convert(chunk, loadingPhotoHandler, subscription, session);
-                        LOG.info("Converted {} XING contacts for user {} in context {}", I(chunk.size()), I(session.getUserId()), I(session.getContextId()));
-                        folderUpdater.save(new SearchIteratorDelegator<Contact>(convertees), subscription);
-                        // Next chunk...
-                        off += chunk.size();
+                    LogProperties.put(LogProperties.Name.SUBSCRIPTION_ADMIN, "true");
+                    try {
+                        int off = startOffset;
+                        while (off < total) {
+                            final int remain = total - off;
+                            final List<User> chunk = xingAPI.getContactsFrom(userId, remain > maxLimit ? maxLimit : remain, off, null, userFields).getUsers();
+                            // Store them
+                            final List<Contact> convertees = convert(chunk, loadingPhotoHandler, subscription, session);
+                            LOG.info("Converted {} XING contacts for user {} in context {}", I(chunk.size()), I(session.getUserId()), I(session.getContextId()));
+                            folderUpdater.save(new SearchIteratorDelegator<>(convertees), subscription);
+                            // Next chunk...
+                            off += chunk.size();
+                        }
+                        return null;
+                    } finally {
+                        LogProperties.remove(LogProperties.Name.SUBSCRIPTION_ADMIN);
                     }
-                    return null;
                 }
             });
             // Return first chunk with this thread
@@ -294,7 +273,7 @@ public class XingSubscribeService extends AbstractOAuthSubscribeService {
      * @return The resulting contacts
      */
     protected List<Contact> convert(final List<User> xingContacts, final PhotoHandler optPhotoHandler, Subscription subscription, final ServerSession session) {
-        final List<Contact> ret = new ArrayList<Contact>(xingContacts.size());
+        final List<Contact> ret = new ArrayList<>(xingContacts.size());
         for (final User xingContact : xingContacts) {
             ret.add(convert(xingContact, optPhotoHandler, subscription, session));
         }
@@ -390,7 +369,7 @@ public class XingSubscribeService extends AbstractOAuthSubscribeService {
         {
             final Map<String, Object> m = xingUser.getProfessionalExperience();
             if (null != m && !m.isEmpty()) {
-                final Map<String, Object> primaryCompany = (Map<String, Object>) m.get("primary_company");
+                final Map<String, Object> primaryCompany = Map.class.cast(m.get("primary_company"));
                 if (null != primaryCompany && !primaryCompany.isEmpty()) {
                     // Name
                     Object s = primaryCompany.get("name");
